"""
Generate latex output comparing time series of given sww files

Inputs:

production dirs: dictionary of output directories with a
                 association to simulation, eg 50m boundary, 100m boundary

gauge_map:       graphical output from make_gauges.py

Outputs:

* latex output to generate figures for report 
* figures used for report stored in the report_figure directory
NOTE, this directory will need to be committed, as well as
the latex files.

June 2006                    
"""

from os import sep, getcwd, F_OK, access, mkdir
import project
from anuga.abstract_2d_finite_volumes.util import sww2timeseries, get_gauges_from_file

# Derive scenario name
p = getcwd().split(sep)
scenario = p[-1] # Last element of absolute CWD path
scenario_name = scenario.split('_2006')[0] # Strip any text past `_2006`
test = scenario_name.split('_')
if len(test) <> 1:
    scenario_name = '%s %s' %(test[0], test[1])
    
# Create report directory
reportdir = getcwd()+sep+'report'+sep
if access(reportdir,F_OK) == 0:
    mkdir (reportdir)

# User defined inputs
report_title = 'Parameter change comparison for ANUGA: %s' %scenario_name.title()
    
# User defined inputs
production_dirs = {'20060704_063005': 'June 2006', # HAT
                   '20061106_223150': 'Nov 2006'} # HAT
                   #'MOST': 'MOST'}

gauge_map = 'onslow_dli_gauge.jpg'

# Create sections and graphs for each designated production directory
latex_output = []
swwfiles = {}
for label_id in production_dirs.keys():
    
    file_loc = project.outputdir + label_id + sep
    swwfile = file_loc + project.basename + '.sww'
    if label_id == 'MOST':
        swwfile = project.boundarydir + project.boundary_basename + '.sww'
    swwfiles[swwfile] = label_id

print 'swwfiles', swwfiles

texname, vec = sww2timeseries(swwfiles,
                              project.gauge_comparison,
                              production_dirs,
                              report = True,
                              reportname = 'latexoutputparameterchange',
                              plot_quantity = ['stage', 'speed'],
                              generate_fig = True,
                              surface = False,
                              time_min = None,
                              time_max = None,
                              title_on = False,
                              verbose = True)

latex_output.append(texname)

# Start report generation
report_name = reportdir + scenario + '_parameter_comparison_onslow.tex'
fid = open(report_name, 'w')

s = """
% This is based on an automatically generated file (by make_report.py).
%
% Manual parts are:
% * an abstract must be written in abstract.tex
% * an introduction must be written in introduction.tex; a basic outline and
%   some of the core inputs are already in place
% * outline of the modelling methodology provided in modelling_methodology.tex
% * the tsunami-genic event should be discussed in tsunami_scenario.tex
% * an computational_setup.tex file needs to be written for the particular scenario
% * the interpretation of the results needs to be written to interpretation.tex
% * maximum inundation maps need to be included in HAT_map.tex and LAT_map.tex etc.
% * damage modelling maps need to be included in HAT_damage and LAT_damage etc.
% * a summary must be written into summary.tex
% * metadata for the scenario data to be included in metadata.tex

\documentclass{article}

\usepackage{ae} % or {zefonts}
\usepackage[T1]{fontenc}
\usepackage[ansinew]{inputenc}
\usepackage{amsmath}
\usepackage{amssymb}
\usepackage{graphicx}
\usepackage{color}
\usepackage[colorlinks]{hyperref}
\usepackage{lscape} %landcape pages support
\usepackage{setspace}
\usepackage{rotating}
\include{appendix}
\setstretch{1.25}
\\topmargin 0pt
\oddsidemargin 0pt
\evensidemargin 0pt
\marginparwidth 0.5pt
\\textwidth \paperwidth
\\advance\\textwidth -2in

"""
fid.write(s)

#s = '\\title{%s} \n' %report_title
#fid.write(s)

s = """
\date{\\today}
%\\author{Geoscience Australia}

\\begin{document}
\\title{
\\begin{figure}[hbt]
  \centerline{ \includegraphics[scale=0.4]{../report_figures/GAlogo.jpg}}
\end{figure}
"""
fid.write(s)

fid.write(s)
s = '%s} '%report_title
fid.write(s)

s = '\maketitle'
fid.write(s)

s = '\\begin{figure}[hbt] \n \centerline{ \includegraphics[width=150mm, height=100mm]{../report_figures/%s}}' %gauge_map
fid.write(s)

s  = """
\caption{Point locations used to compare ANUGA output for Onslow region.}  
\label{fig:comparisonpoints}
\end{figure}
"""
fid.write(s)
    
s = '\input{%s} \n \clearpage \n \n' %latex_output[0]
fid.write(s)

s = '\end{document}'
fid.write(s)

